//
//  CSVExportTableViewController.m
//  AsReaderLR
//
//  Created by mac on 2018/11/27.
//  Copyright © 2018年 asterisk. All rights reserved.
//

#import "CSVExportTableViewController.h"
#import <SVProgressHUD/SVProgressHUD.h>
#import <AsReaderDockSDK/AsReaderDockSDK.h>

@interface CSVExportTableViewController ()<UIDocumentInteractionControllerDelegate, AsReaderDeviceDelegate>
@property (nonatomic,strong)UIDocumentInteractionController *documentController;
@property (nonatomic, strong)NSMutableArray *dataArray;
@property (nonatomic, strong)NSFileManager *fileManager;
@property (nonatomic, strong)NSString *filePath;
@property (nonatomic, retain)AsReaderDevice *m_DeviceCommon;
@end

@implementation CSVExportTableViewController
- (void)viewDidAppear:(BOOL)animated{
    [SVProgressHUD setDefaultMaskType:SVProgressHUDMaskTypeBlack];
    self.m_DeviceCommon  = [AsReaderRFIDDevice sharedInstance];
    self.m_DeviceCommon.delegateDevice  = self;
}

- (void)viewWillDisappear:(BOOL)animated {
    [super viewWillDisappear:animated];
}

- (void)viewDidLoad {
    [super viewDidLoad];
    _dataArray = [NSMutableArray array];
    _fileManager = [NSFileManager defaultManager];
    if ([_typeStr isEqualToString:@"csv"]) {
         self.navigationItem.title = @"CSV List";
    } else if ([_typeStr isEqualToString:@"excel"]) {
         self.navigationItem.title = @"Excel List";
    }
    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    _filePath = [paths objectAtIndex:0];
    [self datasource];
}

- (void)datasource {
    [SVProgressHUD showWithStatus:@"Loading"];
    [_dataArray removeAllObjects];
    NSString *fileStr = _filePath;
    NSMutableArray *array = [NSMutableArray array];

    NSDirectoryEnumerator *enumerator;
    enumerator = [_fileManager enumeratorAtPath:fileStr];
    while((fileStr = [enumerator nextObject]) != nil) {
        [array addObject:fileStr];
    }
    if (array && array.count != 0) {
        for (NSString *str in array) {
            if ([_typeStr isEqualToString:@"csv"]) {
                if ([@"csv" isEqualToString:[str pathExtension]]) {
                    [_dataArray addObject:str];
                }
            } else if ([_typeStr isEqualToString:@"excel"]) {
                if ([@"xlsx" isEqualToString:[str pathExtension]]) {
                    [_dataArray addObject:str];
                }
            }
        }
    }
//    if (arr && arr.count != 0) {
//        for (NSString *str in arr) {
//            NSString *string;
//            if ([str hasPrefix:@"rfid"]) {
//                string = [str substringWithRange:NSMakeRange(5, 14)];
//                [fileNameArray addObject:string];
//            } else if ([str hasPrefix:@"barcode"]) {
//                string = [str substringWithRange:NSMakeRange(8, 14)];
//                [fileNameArray addObject:string];
//            } else if ([str hasPrefix:@"nfc"]) {
//                string = [str substringWithRange:NSMakeRange(4, 14)];
//                [fileNameArray addObject:string];
//            }
//        }
//    }
    [_dataArray sortUsingComparator:^NSComparisonResult(id _Nonnull obj1, id _Nonnull obj2) {
        if ([obj1 integerValue] < [obj2 integerValue]) {
            return NSOrderedDescending;
        } else {
            return NSOrderedAscending;

        }
     }];
//    for (NSString *str in fileNameArray) {
//        for (NSString *string in arr) {
//            if ([string containsString:str]) {
//                [_dataArray addObject:string];
//            }
//        }
//
//    }
    [self.tableView reloadData];
    [SVProgressHUD dismiss];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return _dataArray.count;
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"tableViewCell" forIndexPath:indexPath];
    if (!cell) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:@"tableViewCell"];
    }
    NSString *fileName = [_dataArray objectAtIndex:indexPath.row];
    fileName = [fileName lastPathComponent];
    cell.textLabel.text = fileName;
    return cell;
}

- (NSArray*)tableView:(UITableView *)tableView editActionsForRowAtIndexPath:(nonnull NSIndexPath *)indexPath
{
    UITableViewRowAction *deleteAction = [UITableViewRowAction rowActionWithStyle:UITableViewRowActionStyleNormal title:@"Delete" handler:^(UITableViewRowAction *action, NSIndexPath *indexPath)
                                          {
                                              [tableView setEditing:NO animated:YES];
                                              NSString *fileName = [self->_dataArray objectAtIndex:indexPath.row];
                                              fileName = [self->_filePath stringByAppendingString:[NSString stringWithFormat:@"/%@", fileName]];
                                              if ([self->_fileManager fileExistsAtPath:fileName]) {
                                                  NSError *error;
                                                  [self->_fileManager removeItemAtPath:fileName error:&error];
                                                  NSLog(@"error ===== %@", error);
                                                  [self datasource];
                                              }
                                          }];
    
    deleteAction.backgroundColor = [UIColor redColor];
    return @[deleteAction];
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    NSString *fileName = [_dataArray objectAtIndex:indexPath.row];
    fileName = [_filePath stringByAppendingString:[NSString stringWithFormat:@"/%@", fileName]];
    if ([_fileManager fileExistsAtPath:fileName]) {
         _documentController = [UIDocumentInteractionController interactionControllerWithURL:[NSURL fileURLWithPath:fileName]];
         _documentController.delegate = self;
         [_documentController presentPreviewAnimated:YES];
     }
}


- (UIViewController *)documentInteractionControllerViewControllerForPreview:(UIDocumentInteractionController *)controller {
    return self;
}

- (void)plugged:(BOOL)plug
{
    if(!plug)
    {
        dispatch_async(dispatch_get_main_queue(), ^{
            [self dismissViewControllerAnimated:YES completion:nil];
            [NSThread sleepForTimeInterval:0.2];
            [self.navigationController popToRootViewControllerAnimated:YES];
        });
    }
}

- (void)readerConnected:(int)status {
    
}

- (void)encodeWithCoder:(nonnull NSCoder *)coder {
    
}

@end
