//  KillController.m

#import "KillController.h"
#import "PhyUtility.h"
#import "ModelSettings.h"
#import "GlobalDefine.h"
#import "Utils.h"
#import <AsReaderDockSDK/AsReaderDockSDK.h>
#import "ErrorCodeHelper.h"

@interface KillController ()<AsReaderRFIDDeviceDelegate, AsReaderDeviceDelegate>
@property (weak, nonatomic) IBOutlet UITextField *olTargetEpc;
@property (weak, nonatomic) IBOutlet UITextField *olKillPassword;
@end

@implementation KillController

#pragma mark - Lifecycle
//----------------------------------------------------------------
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    // Do any additional setup after loading the view.
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [AsReaderRFIDDevice sharedInstance].delegateDevice = self;
    [AsReaderRFIDDevice sharedInstance].delegateRFID = self;
    ModelSettings *model = [ModelSettings sharedInstance];
    NSDictionary *dic  = [model.m_arReadTagData objectAtIndex:model.m_nSelectTagNum];
    self.olTargetEpc.text = [PhyUtility getEpcStringFromPcEPCData:[dic objectForKey:df_CELL_TAG_RAW]];
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    [AsReaderRFIDDevice sharedInstance].delegateDevice = self;
    [AsReaderRFIDDevice sharedInstance].delegateRFID = nil;
    [self setOlTargetEpc:nil];
    [self setOlKillPassword:nil];
}

- (void)touchesBegan:(NSSet<UITouch *> *)touches withEvent:(UIEvent *)event
{
    [self.view endEditing:YES];
}

#pragma mark - IBAction
//----------------------------------------------------------------
- (IBAction)rightBarButtonItemClicked:(id)sender
{
    [self.olTargetEpc resignFirstResponder];
    
    NSString *hexaString = self.olKillPassword.text;
    NSScanner *pScanner = [NSScanner scannerWithString: hexaString];
    uint32_t killpassword;
    [pScanner scanHexInt: &killpassword];
    NSData *epcs = [self.olTargetEpc.text hexStringToBytes];
    
    [[AsReaderRFIDDevice sharedInstance] killTagWithPassword:killpassword epc:epcs];
}

#pragma mark - AsReaderRFIDDeviceDelegate
//----------------------------------------------------------------
- (void)killedReceived:(int)statusCode
{
    if(statusCode == 0x00) {
        dispatch_async(dispatch_get_main_queue(), ^{
            [Utils showAlert:@"Confirm" message:@"Killed Tag." view:self];
       });
    }
}

- (void)errorReceived:(NSData *)errorCode{
    ErrorCodeHelper *errorHelper = [ErrorCodeHelper sharedInstance];
      NSString *errorResult = [errorHelper errorReceived:errorCode];

      
          dispatch_async(dispatch_get_main_queue(), ^{
              [Utils showAlert:@"" message:errorResult view:self];
          });
}

- (void)plugged:(BOOL)plug {
    
}

- (void)readerConnected:(int)status {
    
}
@end
